@@ -15,4 +15,4 @@
 # You should have received a copy of the GNU General Public License
 # along with RestAuth.  If not, see <http://www.gnu.org/licenses/>.
 
-__all__ = ['common', 'error', 'restauth_user', 'group', 'content_types']
+version = '0.6.2'
